//
//  RDISFileList.m
//  RDIntegrationSample
//
//  Created by Andrian Budantsov on 08.05.10.
//  Copyright (c) 2010 Readdle. All rights reserved.
//

#import "RDISFileList.h"
#import "RDISHelp.h"
#import "RDIntegration.h"

@implementation RDISFileList


- (void)dealloc {
    [docDir release];
    [selectedFilePath release];
    [super dealloc];
}


- (void)refillFileList {
	NSArray *dirList = [[NSFileManager defaultManager] contentsOfDirectoryAtPath:docDir error:nil];
	
	[fileList release];
	fileList = [[NSMutableArray alloc] initWithCapacity:dirList.count];
	
	NSUInteger i, count = dirList.count;
	for (i = 0; i < count; i++) {
		NSString *path = [dirList objectAtIndex:i];
        
		if ([path hasPrefix:@"."])
			continue;
        
        [fileList addObject:path];
	}
	
	[fileList sortUsingSelector:@selector(compare:)];
}

- (void)refreshFileList {
	[self refillFileList];
	[self.tableView reloadData];
}

- (void)viewDidLoad {
    [super viewDidLoad];
    
    if (!docDir) {
        NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
        docDir = [[paths objectAtIndex:0] retain];
    }
	
	self.title = @"RDIntegration Sample";
	
    self.navigationItem.rightBarButtonItem = self.editButtonItem;
    
    
	UIBarButtonItem *help = [[UIBarButtonItem alloc] initWithTitle:@"Help"
															 style:UIBarButtonItemStylePlain
															target:self 
															action:@selector(openHelp)];
    UISwitch *modeSwitch = [[UISwitch alloc] initWithFrame:CGRectZero];
    [modeSwitch sizeToFit];
    [modeSwitch addTarget:self action:@selector(switchMode:) forControlEvents:UIControlEventValueChanged];
    UIBarButtonItem *integrationMode = [[UIBarButtonItem alloc] initWithCustomView:modeSwitch];
    integrationMode.width = 75;
    [modeSwitch release];
    UILabel *modeLbl = [[UILabel alloc] initWithFrame:CGRectZero];
    [modeLbl setTextColor:[UIColor darkGrayColor]];
    [modeLbl setShadowColor:[UIColor whiteColor]];
    [modeLbl setShadowOffset:CGSizeMake(0, 1)];
    [modeLbl setBackgroundColor:[UIColor clearColor]];
    [modeLbl setText:@"  delete after edit –>"];
    [modeLbl sizeToFit];
    UIBarButtonItem *labelItem = [[UIBarButtonItem alloc] initWithCustomView:modeLbl];
    [modeLbl release];
    UIToolbar *leftToolbar = [[UIToolbar alloc] initWithFrame:CGRectMake(0, 0, 300, 44)];
    leftToolbar.items = @[help, labelItem, integrationMode];
    UIBarButtonItem *leftItem = [[UIBarButtonItem alloc] initWithCustomView:leftToolbar];
    leftItem.width = 300;
	self.navigationItem.leftBarButtonItem = leftItem;
    [leftItem release];
    
	[help release];
	
    [self refillFileList];
	if ([fileList count] == 0) {
		[self performSelector:@selector(openHelp) withObject:nil afterDelay:1.0];
        
        // copy pdf files from resource's directory to docs directory
        NSBundle* myBundle = [NSBundle mainBundle];
        NSString* resourcePath = myBundle.resourcePath; 
        NSArray* arr = [[NSFileManager defaultManager] contentsOfDirectoryAtPath:resourcePath error:nil];
        
        for (NSInteger i = 0; i < [arr count]; i++) {
            NSString *obj = [arr objectAtIndex:i];
            if ([obj hasPrefix:@"."]) 
                continue;
            
            if ([obj hasSuffix:@".pdf"]) {                
                NSString* sourcePath = [resourcePath stringByAppendingPathComponent:obj];
                NSString* destPath = [docDir stringByAppendingPathComponent:obj];
                if ([[NSFileManager defaultManager] fileExistsAtPath:sourcePath] && destPath)
                    [[NSFileManager defaultManager] copyItemAtPath:sourcePath toPath:destPath error:nil];  
            }
        }
        
        [self refreshFileList];
    } else {
        
        [self.tableView reloadData];
    }
}

- (void)openHelp {
	RDISHelp *help = [[RDISHelp alloc] init];
	[self presentViewController:help animated:YES completion:nil];
	[help release];
}

- (void)switchMode:(UISwitch *)sender
{
    [[RDIntegration sharedIntegration] setDeleteFromReaddleAppAfterEdit:[sender isOn]];
}


- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Override to allow orientations other than the default portrait orientation.
    return YES;
}


#pragma mark -
#pragma mark Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    // Return the number of sections.
    return 1;
}


- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    // Return the number of rows in the section.
    return [fileList count];
}


// Customize the appearance of table view cells.
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    
    static NSString *CellIdentifier = @"Cell";
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleValue1 reuseIdentifier:CellIdentifier] autorelease];
    }
    
    // Configure the cell...
	NSString *fileName = (NSString *)[fileList objectAtIndex:indexPath.row];
    cell.textLabel.text = fileName;
    
    // get the modification date
    NSString* fullPath = [docDir stringByAppendingPathComponent:fileName]; 
    NSDate* fileModificationDate = nil; 
    NSDictionary *attr = [[NSFileManager defaultManager] attributesOfItemAtPath:fullPath error:nil];
    fileModificationDate = [attr fileModificationDate];
    
    NSDateFormatter *dateFormatter = [[NSDateFormatter alloc] init];
    [dateFormatter setDateFormat:@"dd-MM-yyyy  /  hh:mm:ss"];
    NSString *strDate = [dateFormatter stringFromDate:fileModificationDate];
    
    cell.detailTextLabel.text = strDate;
    
    [dateFormatter release];
    return cell;
}


- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle
forRowAtIndexPath:(NSIndexPath *)indexPath
{
    
    if (editingStyle == UITableViewCellEditingStyleDelete) {
		NSString *n = [fileList objectAtIndex:indexPath.row];
		
		[[NSFileManager defaultManager] removeItemAtPath:[docDir stringByAppendingPathComponent:n] error:nil];
		
		[fileList removeObjectAtIndex:indexPath.row];

        [tableView deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:YES];
    }    
}


#pragma mark -
#pragma mark Table view delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
	NSString *fullName = [fileList objectAtIndex:indexPath.row];
	NSString *fullpath = [docDir stringByAppendingPathComponent:fullName];
    
    [selectedFilePath release];
    selectedFilePath = [fullpath retain];
    
    UIActionSheet *actionSheet =
    [[UIActionSheet alloc] initWithTitle:nil
                                delegate:self
                       cancelButtonTitle:@"Cancel"
                  destructiveButtonTitle:nil
                       otherButtonTitles:@"Open in PDF Expert", @"Edit in PDF Expert", @"Edit in PDFExpert with flattening",
                                        nil];
    
    [actionSheet showFromRect:[tableView rectForRowAtIndexPath:indexPath] inView:tableView animated:YES];

    [actionSheet release];
}

- (void)actionSheet:(UIActionSheet *)actionSheet clickedButtonAtIndex:(NSInteger)buttonIndex {
    if (!selectedFilePath)
        return;
    
    switch (buttonIndex) {
        case 0://Open
            [[RDIntegration sharedIntegration] openFile:[NSURL fileURLWithPath:selectedFilePath]
                                                  inApp:RDIntegrationAppPDFExpertAny
                                             completion:nil];
            break;

        case 1://Edit
            [[RDIntegration sharedIntegration] editFile:[NSURL fileURLWithPath:selectedFilePath]
                                                  inApp:RDIntegrationAppPDFExpertAny
                                         withFlattening:NO
                                               userInfo:@{@"file_path" : selectedFilePath}
                                             completion:^(NSError *error) {
                                                 if (error) {
                                                     NSLog(@"RDIntegration error: %@", error);
                                                 }
                                             }];
            break;
            
        case 2://Edit with flattening
            [[RDIntegration sharedIntegration] editFile:[NSURL fileURLWithPath:selectedFilePath]
                                                  inApp:RDIntegrationAppPDFExpertAny
                                         withFlattening:YES
                                               userInfo:@{@"file_path" : selectedFilePath}
                                             completion:^(NSError *error) {
                                                 if (error) {
                                                     NSLog(@"RDIntegration error: %@", error);
                                                 }
                                             }];
            break;
            
        default:
            break;
    }

    NSIndexPath *indexPath = [self.tableView indexPathForSelectedRow];
    [self.tableView deselectRowAtIndexPath:indexPath animated:NO];

    [selectedFilePath release];
    selectedFilePath = nil;
}

- (void)popoverControllerDidDismissPopover:(UIPopoverController *)popoverController {
	[popoverController release];
}

@end

