//
//  RDIntegration.h
//  RDIntegration
//
//  Created by Andrian Budantsov on 08.05.12.
//  Copyright (c) 2012 Readdle. All rights reserved.
//

#import <Foundation/Foundation.h>
NS_ASSUME_NONNULL_BEGIN

@class RDIntegration, RDIntegrationContext;

typedef NS_ENUM(NSUInteger, RDIntegrationFileConflictResolvingResult) {
    RDIntegrationFileConflictResolvingResultDefaultBehaviour,
    RDIntegrationFileConflictResolvingResultDeleteOldFile,
    RDIntegrationFileConflictResolvingResultRenameNewFile,
    RDIntegrationFileConflictResolvingResultRenameOldFile
};

typedef NS_ENUM(NSUInteger, RDIntegrationAppType) {
    RDIntegrationAppPDFExpert,
    RDIntegrationAppPDFExpertEnterprise,
    RDIntegrationAppPDFExpertAny,
    RDIntegrationAppReaddleDocs
};


@protocol RDIntegrationDelegate <NSObject>

@optional
- (NSURL *)destinationFolderURLForURLPasteboardIntegration:(RDIntegration *)integration withContext:(RDIntegrationContext *)context;
- (BOOL)URLPasteboardIntegration:(RDIntegration *)integration requiresFileWithContext:(RDIntegrationContext *)context;
- (RDIntegrationFileConflictResolvingResult)conflictResolutionPolicyForURLPasteboardIntegration:(RDIntegration *)integration
                                                                                    withContext:(RDIntegrationContext *)context;

- (void)URLPasteboardIntegration:(RDIntegration *)integration willStartSavingToFolder:(NSURL *)fileURL withContext:(RDIntegrationContext *)context;
- (void)URLPasteboardIntegration:(RDIntegration *)integration didFinishSavingWithURL:(NSURL *)fileURL withContext:(RDIntegrationContext *)context;

- (void)URLPasteboardIntegration:(RDIntegration *)integration didHandleURL:(NSURL *)url withContext:(RDIntegrationContext *)context;
- (void)URLPasteboardIntegration:(RDIntegration *)integration didFailWithError:(NSError *)error withContext:(RDIntegrationContext *)context;
@end



@interface RDIntegration : NSObject

@property (nonatomic, assign) BOOL deleteFromReaddleAppAfterEdit;
@property (nonatomic, weak) id <RDIntegrationDelegate> delegate;

+ (RDIntegration *)sharedIntegration;
+ (RDIntegration *)defaultIntegration;
+ (void)setDefaultIntegration:(RDIntegration *)integration;

- (instancetype)initWithSchemesAndActions:(NSDictionary *)registeredActions;

- (BOOL)hasApp:(RDIntegrationAppType)appType;
- (BOOL)handleOpenURL:(nullable NSURL *)url;

- (void)openFile:(NSURL *)fileURL
           inApp:(RDIntegrationAppType)appType
      completion:(nullable void (^)(NSError *))completion;

// Editing with returned annotated file back to App

- (void)editFile:(NSURL *)fileURL
           inApp:(RDIntegrationAppType)appType
  withFlattening:(BOOL)isFlatteningNeeded
        userInfo:(nullable NSDictionary *)userInfo
      completion:(nullable void (^)(NSError *))completion;

@end
NS_ASSUME_NONNULL_END
